@@ -11,11 +11,11 @@ variables::
     sage: env = {k:v for (k,v) in os.environ.items() if not k.startswith("SAGE_")}
     sage: import subprocess
     sage: cmd = "from sage.all import SAGE_ROOT; print(SAGE_ROOT)"
-    sage: res = subprocess.call(["python2", "-c", cmd], env=env)  # long time
+    sage: res = subprocess.call([sys.executable, "-c", cmd], env=env)  # long time
     None
 """
 
-#*****************************************************************************
+# ****************************************************************************
 #       Copyright (C) 2013 R. Andrew Ohana <andrew.ohana@gmail.com>
 #       Copyright (C) 2019 Jeroen Demeyer <J.Demeyer@UGent.be>
 #
@@ -24,7 +24,7 @@ variables::
 # the Free Software Foundation, either version 2 of the License, or
 # (at your option) any later version.
 #                  https://www.gnu.org/licenses/
-#*****************************************************************************
+# ****************************************************************************
 
 from __future__ import absolute_import
 
@@ -182,7 +182,9 @@ var('CREMONA_LARGE_DATA_DIR',        join(SAGE_SHARE, 'cremona'))
 var('JMOL_DIR',                      join(SAGE_SHARE, 'jmol'))
 var('JSMOL_DIR',                     join(SAGE_SHARE, 'jsmol'))
 var('MATHJAX_DIR',                   join(SAGE_SHARE, 'mathjax'))
+var('MTXLIB',                        join(SAGE_SHARE, 'meataxe'))
 var('THREEJS_DIR',                   join(SAGE_SHARE, 'threejs'))
+var('PPLPY_DOCS',                    join(SAGE_SHARE, 'doc', 'pplpy'))
 var('MAXIMA_FAS')
 
 # misc
