@@ -43,7 +43,6 @@ from sage.categories.finite_fields import FiniteFields
 from sage.categories.homset import Hom, End
 from sage.categories.number_fields import NumberFields
 from sage.interfaces.all import singular
-import sage.libs.singular
 
 from sage.misc.all import add
 
@@ -444,48 +443,35 @@ class AffineCurve(Curve_generic, AlgebraicScheme_subscheme_affine):
             sage: C = Curve([y^2 - a*x^5, x - z], A)
             sage: B = C.blowup()
             sage: B[0]
-            (Affine Curve over Number Field in a with defining polynomial x^2 - 2 defined by s2 - 1,
-            2*x^3 + (-a)*s1^2,
-             Affine Curve over Number Field in a with defining polynomial x^2 - 2 defined by s0 - s2,
-             2*y^3*s2^5 + (-a),
-             Affine Curve over Number Field in a with defining polynomial x^2 - 2 defined by s0 - 1,
-             2*z^3 + (-a)*s1^2)
+            (Affine Curve over Number Field in a with defining polynomial x^2 - 2 with a = 1.414213562373095? defined by s2 - 1, 2*x^3 + (-a)*s1^2,
+             Affine Curve over Number Field in a with defining polynomial x^2 - 2 with a = 1.414213562373095? defined by s0 - s2, 2*y^3*s2^5 + (-a),
+             Affine Curve over Number Field in a with defining polynomial x^2 - 2 with a = 1.414213562373095? defined by s0 - 1, 2*z^3 + (-a)*s1^2)
             sage: B[1][0][2]
             Scheme morphism:
-            From: Affine Curve over Number Field in a with defining polynomial x^2 - 2 defined by s2 - 1,
-            2*x^3 + (-a)*s1^2
-            To:   Affine Curve over Number Field in a with defining polynomial x^2 - 2 defined by s0 - 1,
-            2*z^3 + (-a)*s1^2
-            Defn: Defined on coordinates by sending (x, s1, s2) to
-                  (x*s2, 1/s2, s1/s2)
+              From: Affine Curve over Number Field in a with defining polynomial x^2 - 2 with a = 1.414213562373095? defined by s2 - 1, 2*x^3 + (-a)*s1^2
+              To:   Affine Curve over Number Field in a with defining polynomial x^2 - 2 with a = 1.414213562373095? defined by s0 - 1, 2*z^3 + (-a)*s1^2
+              Defn: Defined on coordinates by sending (x, s1, s2) to
+                    (x*s2, 1/s2, s1/s2)
             sage: B[1][2][0]
             Scheme morphism:
-            From: Affine Curve over Number Field in a with defining polynomial x^2 - 2 defined by s0 - 1,
-            2*z^3 + (-a)*s1^2
-            To:   Affine Curve over Number Field in a with defining polynomial x^2 - 2 defined by s2 - 1,
-            2*x^3 + (-a)*s1^2
-            Defn: Defined on coordinates by sending (z, s0, s1) to
-                  (z*s0, s1/s0, 1/s0)
+              From: Affine Curve over Number Field in a with defining polynomial x^2 - 2 with a = 1.414213562373095? defined by s0 - 1, 2*z^3 + (-a)*s1^2
+              To:   Affine Curve over Number Field in a with defining polynomial x^2 - 2 with a = 1.414213562373095? defined by s2 - 1, 2*x^3 + (-a)*s1^2
+              Defn: Defined on coordinates by sending (z, s0, s1) to
+                    (z*s0, s1/s0, 1/s0)
             sage: B[2]
             (Scheme morphism:
-            From: Affine Curve over Number Field in a with defining polynomial x^2 - 2 defined by
-            s2 - 1, 2*x^3 + (-a)*s1^2
-            To:   Affine Curve over Number Field in a with defining polynomial x^2 - 2 defined by
-            (-a)*x^5 + y^2, x - z
-            Defn: Defined on coordinates by sending (x, s1, s2) to
-                  (x, x*s1, x*s2), Scheme morphism:
-            From: Affine Curve over Number Field in a with defining polynomial x^2 - 2 defined by
-            s0 - s2, 2*y^3*s2^5 + (-a)
-            To:   Affine Curve over Number Field in a with defining polynomial x^2 - 2 defined by
-            (-a)*x^5 + y^2, x - z
-            Defn: Defined on coordinates by sending (y, s0, s2) to
-                  (y*s0, y, y*s2), Scheme morphism:
-            From: Affine Curve over Number Field in a with defining polynomial x^2 - 2 defined by
-            s0 - 1, 2*z^3 + (-a)*s1^2
-            To:   Affine Curve over Number Field in a with defining polynomial x^2 - 2 defined by
-            (-a)*x^5 + y^2, x - z
-            Defn: Defined on coordinates by sending (z, s0, s1) to
-                  (z*s0, z*s1, z))
+               From: Affine Curve over Number Field in a with defining polynomial x^2 - 2 with a = 1.414213562373095? defined by s2 - 1, 2*x^3 + (-a)*s1^2
+               To:   Affine Curve over Number Field in a with defining polynomial x^2 - 2 with a = 1.414213562373095? defined by (-a)*x^5 + y^2, x - z
+               Defn: Defined on coordinates by sending (x, s1, s2) to
+                     (x, x*s1, x*s2), Scheme morphism:
+               From: Affine Curve over Number Field in a with defining polynomial x^2 - 2 with a = 1.414213562373095? defined by s0 - s2, 2*y^3*s2^5 + (-a)
+               To:   Affine Curve over Number Field in a with defining polynomial x^2 - 2 with a = 1.414213562373095? defined by (-a)*x^5 + y^2, x - z
+               Defn: Defined on coordinates by sending (y, s0, s2) to
+                     (y*s0, y, y*s2), Scheme morphism:
+               From: Affine Curve over Number Field in a with defining polynomial x^2 - 2 with a = 1.414213562373095? defined by s0 - 1, 2*z^3 + (-a)*s1^2
+               To:   Affine Curve over Number Field in a with defining polynomial x^2 - 2 with a = 1.414213562373095? defined by (-a)*x^5 + y^2, x - z
+               Defn: Defined on coordinates by sending (z, s0, s1) to
+                     (z*s0, z*s1, z))
 
         ::
 
@@ -1012,16 +998,16 @@ class AffinePlaneCurve(AffineCurve):
                 yt = lcs[1]
                 xt = lcs[0]
                 ldg = degree_lowest_rational_function(r(xt, yt), t)
-                if ldg[0] != 0:
-                    divf.append([ldg[0], pt0])
+                if ldg != 0:
+                    divf.append([ldg, pt0])
         return divf
 
     def local_coordinates(self, pt, n):
         r"""
         Return local coordinates to precision n at the given point.
 
-            Behaviour is flaky - some choices of `n` are worst that
-            others.
+        Behaviour is flaky - some choices of `n` are worst that
+        others.
 
 
         INPUT:
@@ -1065,17 +1051,15 @@ class AffinePlaneCurve(AffineCurve):
         S.eval('poly f = '+str(ft) + ';')
         c = S('coeffs(%s, t)' % ft)
         N = int(c.size())
-        b = ["%s[%s,1]," % (c.name(), i) for i in range(2,N//2-4)]
-        b = ''.join(b)
-        b = b[:len(b)-1] # to cut off the trailing comma
-        cmd = 'ideal I = '+b
+        b = ','.join("%s[%s,1]" % (c.name(), i) for i in range(2, N//2-4))
+        cmd = 'ideal I = ' + b
         S.eval(cmd)
         S.eval('short=0')    # print using *'s and ^'s.
         c = S.eval('slimgb(I)')
         d = c.split("=")
         d = d[1:]
         d[len(d)-1] += "\n"
-        e = [x[:x.index("\n")] for x in d]
+        e = [xx[:xx.index("\n")] for xx in d]
         vals = []
         for x in e:
             for y in vars0:
@@ -1090,9 +1074,7 @@ class AffinePlaneCurve(AffineCurve):
                     else:
                         vals.append([eval(str(y)[1:]),str(y),F(0)])
         vals.sort()
-        k = len(vals)
-        v = [x0+t,y0+add([vals[i][2]*t**(i+1) for i in range(k)])]
-        return v
+        return [x0 + t, y0 + add(v[2] * t**(j+1) for j, v in enumerate(vals))]
 
     def plot(self, *args, **kwds):
         r"""
@@ -1355,10 +1337,9 @@ class AffinePlaneCurve(AffineCurve):
                     T = T(1, vars[1])
                     roots = T.univariate_polynomial().roots()
                     fact.extend([vars[1] - roots[i][0]*vars[0] for i in range(len(roots))])
-            return [f(coords) for f in fact]
+            return [ff(coords) for ff in fact]
         else:
-            fact = T.factor()
-            return [l[0](coords) for l in fact]
+            return [l[0](coords) for l in T.factor()]
 
     def is_ordinary_singularity(self, P):
         r"""
