@@ -401,9 +401,12 @@ class EnumeratedSetFromIterator(Parent):
         TESTS::
 
             sage: from sage.sets.set_from_iterator import EnumeratedSetFromIterator
-            sage: from six.moves import range
             sage: S = EnumeratedSetFromIterator(range, args=(1,4))
-            sage: S(1)  # indirect doctest
+            sage: S(1)  # py2
+            1
+
+            sage: S(1)  # py3
+            doctest:...: UserWarning: Testing equality of infinite sets which will not end in case of equality
             1
             sage: S(0)  # indirect doctest
             Traceback (most recent call last):
@@ -751,10 +754,14 @@ class EnumeratedSetFromIterator_method_caller(Decorator):
 
         But not the enumerated set::
 
-            sage: loads(dumps(d.f()))
+            sage: loads(dumps(d.f())) # py2
             Traceback (most recent call last):
             ...
             PicklingError: Can't pickle <... 'function'>: attribute lookup __builtin__.function failed
+            sage: loads(dumps(d.f())) # py3
+            Traceback (most recent call last):
+            ...
+            _pickle.PicklingError: Can't pickle <function DummyExampleForPicklingTest.f at ...>: it's not the same object as sage.sets.set_from_iterator.DummyExampleForPicklingTest.f
         """
         self.inst = inst
         self.f = f
